@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003 - 2023  Razvan Cojocaru <rzvncj@gmail.com>
+  Copyright (C) 2003 - 2024  Razvan Cojocaru <rzvncj@gmail.com>
    XML-RPC/Context ID code contributed by Eamon Millman / PCI Geomatics
   <millman@pcigeomatics.com>
   Tree control icons code (and the icons) contributed by Fritz Elfert
@@ -109,7 +109,7 @@ const wxChar* about_txt = wxT("xCHM v. " VERSION
 CHMFrame::CHMFrame(const wxString& title, const wxString& booksDir, const wxPoint& pos, const wxSize& size,
                    const wxString& normalFont, const wxString& fixedFont, int fontSize, int sashPosition,
                    const wxString& fullAppPath, bool loadTopics, bool loadIndex)
-    : wxFrame(nullptr, -1, title, pos, size), _openPath(booksDir), _normalFont(normalFont), _fixedFont(fixedFont),
+    : wxFrame(nullptr, wxID_ANY, title, pos, size), _openPath(booksDir), _normalFont(normalFont), _fixedFont(fixedFont),
       _sashPos(sashPosition), _fullAppPath(fullAppPath), _loadTopics(loadTopics), _loadIndex(loadIndex)
 {
 #if wxUSE_ACCEL
@@ -196,7 +196,9 @@ void CHMFrame::OnOpen(wxCommandEvent&)
         return;
 
     _openPath = selection.BeforeLast(wxT('/'));
-    LoadCHM(selection);
+
+    if (!LoadCHM(selection))
+        wxMessageBox(_("Could not open file") + " " + selection, _("Error"), wxOK | wxCENTRE | wxICON_ERROR, this);
 }
 
 void CHMFrame::OnChangeFonts(wxCommandEvent&)
@@ -304,8 +306,8 @@ void CHMFrame::OnHistFile(wxCommandEvent& event)
 {
     auto f = _fh.GetHistoryFile(event.GetId() - wxID_FILE1);
 
-    if (!f.IsEmpty())
-        LoadCHM(f);
+    if (!f.IsEmpty() && !LoadCHM(f))
+        wxMessageBox(_("Could not open file") + " " + f, _("Error"), wxOK | wxCENTRE | wxICON_ERROR, this);
 }
 
 void CHMFrame::OnFind(wxCommandEvent& event)
@@ -688,7 +690,7 @@ wxPanel* CHMFrame::CreateContentsPanel()
 {
     auto temp   = new wxPanel(_nb);
     auto sizer  = new wxBoxSizer(wxVERTICAL);
-    auto bmarks = new wxStaticBoxSizer(new wxStaticBox(temp, -1, _("Bookmarks")), wxVERTICAL);
+    auto bmarks = new wxStaticBoxSizer(new wxStaticBox(temp, wxID_ANY, _("Bookmarks")), wxVERTICAL);
     auto inner  = new wxBoxSizer(wxHORIZONTAL);
 
     temp->SetAutoLayout(true);
